##  Keyboard Navigation and Shortcuts
When editing a dashboard, you can use keyboard keys and shortcuts to navigate between the dashboard panels, move, or resize them.
### Navigation
Action | Key
---|---
Navigate between panels and elements in the panel | ↹ (Tab)


### Moving Selected Panels
Action | Key
---|---
Move a selected panel one unit to the right | → (Right Arrow)
Move a selected panel one unit to the left | ← (Left Arrow)
Move a selected panel one unit down | ↓ (Down Arrow)
Move a selected panel one unit up | ↑ (Up Arrow)


### Resizing Selected Panels
Action | Shortcuts for Windows | Shortcuts for Mac
---|---|---
Scale up a selected panel by one unit to the right | Alt + → (Right Arrow) | ⌥ (Option) + → (Right Arrow)
Scale up a selected panel by one unit to the bottom | Alt + ↓ (Down Arrow) | ⌥ (Option) + ↓ (Down Arrow)
Scale down a selected panel by one unit from the right | Alt + ← (Left Arrow) | ⌥ (Option) + ← (Left Arrow)
Scale down a selected panel by one unit from the bottom | Alt + ↑ (Up Arrow) | ⌥ (Option) + ↑ (Up Arrow)


YesNo
Send
